@@ -3,12 +3,14 @@
 require 'money/locale_backend/errors'
 require 'money/locale_backend/legacy'
 require 'money/locale_backend/i18n'
+require 'money/locale_backend/currency'
 
 class Money
   module LocaleBackend
     BACKENDS = {
       legacy: Money::LocaleBackend::Legacy,
-      i18n: Money::LocaleBackend::I18n
+      i18n: Money::LocaleBackend::I18n,
+      currency: Money::LocaleBackend::Currency
     }.freeze
 
     def self.find(name)
